from connector.generated import (
    CapabilityName,
    OAuthCredential,
    OAuthScopes,
    OAuthSettings,
    ValidateCredentialsRequest,
    ValidateCredentialsResponse,
    ValidatedCredentials,
)
from connector.oai.integration import Integration


async def test_scopes_for_capabilities():
    """Test if scopes are set for each implemented capability."""
    app_id = "test"
    integration = Integration(
        app_id=app_id,
        auth=OAuthCredential,
        oauth_settings=OAuthSettings(
            authorization_url="https://test.com/authorize",
            token_url="https://test.com/token",
            scopes=OAuthScopes(
                validate_credentials="test",
            ),
        ),
        exception_handlers=[],
        handle_errors=True,
    )

    @integration.register_capability(CapabilityName.VALIDATE_CREDENTIALS)
    async def validate_credentials(args: ValidateCredentialsRequest) -> ValidateCredentialsResponse:
        return ValidateCredentialsResponse(
            response=ValidatedCredentials(
                valid=True,
                unique_tenant_id="test",
            ),
        )

    for capability in integration.capabilities:
        assert integration.oauth_settings and integration.oauth_settings.scopes is not None
        if capability.value not in [
            "get_authorization_url",
            "handle_authorization_callback",
            "refresh_access_token",
        ]:
            assert capability.value in integration.oauth_settings.scopes.model_dump().keys()
